Distribution:   CCux
Packager:	Christian Wasem <wasem@ccux-linux.de>

Name:		mysql
Summary:        MySQL is a very fast and reliable SQL database server
Version:	5.0.51b
Release:	3

License:	GNU/GPL
URL:		http://www.mysql.com
Group:		Databases
Source0:	%{name}-%{version}.tar.gz
Source1:	%{name}-initscript
Source2:	%{name}.conf

BuildRoot:	%{_tmppath}/%{name}-buildroot

Prereq(post,preun): /sbin/install-info
Prereq(post,preun): /sbin/chkconfig
BuildRequires:	glibc-devel 
BuildRequires:	readline-devel 
BuildRequires:	ncurses-devel 
BuildRequires:	openssl-devel
BuildRequires:	libstdc++-devel 
BuildRequires:	zlib-devel
BuildRequires:	bash
BuildRequires:	perl

%define		mysql_datadir	/var/lib/mysql
%define		mysql_user	mysql
%define		mysql_group	mysql

%description
The MySQL(TM) software delivers a very fast, multi-threaded, multi-user,
and robust SQL (Structured Query Language) database server. MySQL Server
is intended for mission-critical, heavy-load production systems as well
as for embedding into mass-deployed software. MySQL is a trademark of
MySQL AB.

The MySQL software has Dual Licensing, which means you can use the MySQL
software free of charge under the GNU General Public License
(http://www.gnu.org/licenses/). You can also purchase commercial MySQL
licenses from MySQL AB if you do not wish to be bound by the terms of
the GPL. See the chapter "Licensing and Support" in the manual for
further info.

The MySQL web site (http://www.mysql.com/) provides the latest
news and information about the MySQL software. Also please see the
documentation and the manual for more information.

%package	devel
Summary:	%{name} development headers.
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description	devel
Header and include files for developing applications with %{name}.

%pre
# Add User/Group only when fresh installed,not for upgrades!
if [ $1 -eq 1 ]; then
    groupadd -g 50 %{mysql_group} &>/dev/null || :
    useradd -s /sbin/nologin -g %{mysql_group} -u 50 %{mysql_user} &>/dev/null || :
fi

%post
# is the mysql-db already installed ?
# if not install it
if  ! [ -f %{mysql_datadir}/mysql-bin.index ]; 
then
    mysql_install_db --user=%{mysql_user} &>/dev/null || :
    chown -R mysql:mysql %{mysql_datadir}
fi
# Install info files
/sbin/install-info %_infodir/mysql.info.gz %_infodir/dir
ldconfig
# Add to init process and activate
/sbin/chkconfig --add mysql
/sbin/chkconfig mysql on
# Restart mysql if we are upgrading...
if test $1 -gt 1; then
        /etc/rc.d/init.d/mysql stop 1>/dev/null 2>&1
        /etc/rc.d/init.d/mysql start 1>/dev/null 2>&1
fi

%preun
# Stop mysql and remove initscript 
if test $1 = 0; then
        /etc/rc.d/init.d/mysql stop 1>/dev/null 2>&1
        /sbin/chkconfig --del mysql
fi
# Remove User/Group only when removing finally
if [ $1 -eq 0 ]; then
    /usr/sbin/userdel %{mysql_user} &>/dev/null || :
    /usr/sbin/groupdel %{mysql_group} &>/dev/null || :
fi
# Remove info files
if [ "$1" = 0 ]; then
    /sbin/install-info --del %_infodir/mysql.info.gz %_infodir/dir
fi 

%postun
rm -fR %{mysql_datadir}
ldconfig

%prep
%setup -n %{name}-%{version}

%build
CPPFLAGS="-D_GNU_SOURCE" ./configure --prefix=%_prefix \
--sysconfdir=%_sysconfdir \
--mandir=%_mandir \
--infodir=%_infodir \
--libexecdir=%_sbindir \
--localstatedir=%{mysql_datadir} \
--enable-thread-safe-client \
--enable-assembler \
--enable-local-infile \
--with-named-thread-libs=-lpthread \
--with-unix-socket-path=/var/run/mysqld/mysqld.sock \
--with-mysqld-user=%{mysql_user} \
--without-debug \
--without-bench \
--without-readline \
--with-libwrap \
--with-openssl \
--with-berkeley-db \
--with-extra-charsets=all \
--disable-dependency-tracking
make

%install
make install DESTDIR=$RPM_BUILD_ROOT

# Creating required directories
mkdir -p $RPM_BUILD_ROOT/{etc/rc.d/init.d,%{mysql_datadir}}

# Copy initscript to init.d
install -m 755 %{SOURCE1} $RPM_BUILD_ROOT%_sysconfdir/rc.d/init.d/%{name}

# Creating sharing libraries for other programms
cd $RPM_BUILD_ROOT%_libdir
ln -v -sf %{name}/libmysqlclient{,_r}.so* $RPM_BUILD_ROOT%_libdir

# Add mysql configuration to /etc
install -m644 %{SOURCE2} $RPM_BUILD_ROOT%_sysconfdir/my.cnf

# Remove mysql-test directory
rm -R $RPM_BUILD_ROOT%_prefix/%{name}-test

%files
%defattr(-,root,root)
%config(noreplace) %_sysconfdir/my.cnf
%_sysconfdir/rc.d/init.d/%{name}
/var/lib/%{name}
%_bindir
%_sbindir
%_libdir/*.so
%_libdir/*.so.*
%_libdir/%{name}/*.so
%_libdir/%{name}/*.so.*
%_datadir

%files devel
%defattr(-,root,root)
%_includedir
%_libdir/%{name}/*.a
%_libdir/%{name}/*.la

%clean
rm -rf $RPM_BUILD_ROOT

%changelog
* Sat May 17 2008 Christian Wasem <wasem@ccux-linux.de> 5.0.51b-3
- fixed wrong mysqld pid file in init-script
* Tue May 13 2008 Christian Wasem <wasem@ccux-linux.de> 5.0.51b-2
- fixed wrong mysql_datadir, specfile tweaking
* Mon May 05 2008 Karsten Brockmann <arcam@ccux-linux.de> 5.0.51b-1
- Version update
* Thu Dec 13 2007 Karsten Brockmann <arcam@ccux-linux.de> 5.0.51-1
- Version update
* Fri Jan 19 2007 Christian Wasem <wasem@ccux-linux.de> 5.0.27-1
- Version update
* Wed Oct 11 2006 Karsten Brockmann <arcam@ccux-linux.de> 5.0.26-1
- Version update
- ported initscript to support chkconfig
* Sun Sep 11 2005 Christian Wasem <wasem@ccux-linux.de> 4.1.14-1
- Update to Version 4.1.14 for SourceRPM